@@ -4,8 +4,10 @@ pub mod crossterm_event_handler;
 pub mod game_engine;
 pub mod image;
 pub mod network;
+#[cfg(feature = "relayer")]
 pub mod relayer;
 pub mod space_adventure;
+#[cfg(feature = "ssh")]
 pub mod ssh;
 pub mod store;
 pub mod tui;
