@@ -33,10 +33,7 @@ static ASTEROID_IMAGE_DATA: Lazy<HashMap<(AsteroidSize, usize), (Gif, Vec<HitBox
                 let mut hit_boxes = vec![];
 
                 let path = if size == AsteroidSize::Planet {
-                    format!(
-                        "asteroids/asteroid{}.png",
-                        rand::thread_rng().gen_range(0..30)
-                    )
+                    format!("asteroids/asteroid{}.png", rand::rng().random_range(0..30))
                 } else {
                     format!(
                         "space_adventure/asteroid_{}{}.png",
@@ -281,7 +278,7 @@ impl Entity for AsteroidEntity {
                     true
                 };
 
-                let rng = &mut ChaCha8Rng::from_entropy();
+                let rng = &mut ChaCha8Rng::from_os_rng();
                 let mut callbacks = vec![];
                 let position = self.position;
 
@@ -289,12 +286,12 @@ impl Entity for AsteroidEntity {
                     AsteroidSize::Planet => {}
                     AsteroidSize::Huge => {
                         for _ in 0..3 {
-                            if rng.gen_bool(0.95) {
+                            if rng.random_bool(0.95) {
                                 callbacks.push(SpaceCallback::GenerateAsteroid {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-4.5..4.5),
-                                        rng.gen_range(-4.5..4.5),
+                                        rng.random_range(-4.5..4.5),
+                                        rng.random_range(-4.5..4.5),
                                     ),
                                     size: AsteroidSize::Big,
                                 });
@@ -302,12 +299,12 @@ impl Entity for AsteroidEntity {
                         }
 
                         for _ in 0..4 {
-                            if rng.gen_bool(0.75) {
+                            if rng.random_bool(0.75) {
                                 callbacks.push(SpaceCallback::GenerateAsteroid {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-5.5..5.5),
-                                        rng.gen_range(-5.5..5.5),
+                                        rng.random_range(-5.5..5.5),
+                                        rng.random_range(-5.5..5.5),
                                     ),
                                     size: AsteroidSize::Small,
                                 });
@@ -315,43 +312,44 @@ impl Entity for AsteroidEntity {
                         }
 
                         for _ in 0..8 {
-                            if rng.gen_bool(0.85) {
+                            if rng.random_bool(0.85) {
                                 callbacks.push(SpaceCallback::GenerateParticle {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     color: Rgba([
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
                                         255,
                                     ]),
                                     particle_state: EntityState::Decaying {
-                                        lifetime: 2.0 + rng.gen_range(0.0..1.5),
+                                        lifetime: 2.0 + rng.random_range(0.0..1.5),
                                     },
-                                    layer: rng.gen_range(0..=2),
+                                    layer: rng.random_range(0..=2),
                                 });
                             }
-                            if should_emit_fragments && rng.gen_bool(0.15) {
+                            if should_emit_fragments && rng.random_bool(0.15) {
                                 callbacks.push(SpaceCallback::GenerateFragment {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     resource: Resource::SCRAPS,
                                     amount: 1,
                                 });
                             }
-                            if should_emit_fragments && rng.gen_bool(self.gold_fragment_probability)
+                            if should_emit_fragments
+                                && rng.random_bool(self.gold_fragment_probability)
                             {
                                 callbacks.push(SpaceCallback::GenerateFragment {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-7.5..7.5),
-                                        rng.gen_range(-7.5..7.5),
+                                        rng.random_range(-7.5..7.5),
+                                        rng.random_range(-7.5..7.5),
                                     ),
                                     resource: Resource::GOLD,
                                     amount: 1,
@@ -361,12 +359,12 @@ impl Entity for AsteroidEntity {
                     }
                     AsteroidSize::Big => {
                         for _ in 0..3 {
-                            if rng.gen_bool(0.85) {
+                            if rng.random_bool(0.85) {
                                 callbacks.push(SpaceCallback::GenerateAsteroid {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-4.5..4.5),
-                                        rng.gen_range(-4.5..4.5),
+                                        rng.random_range(-4.5..4.5),
+                                        rng.random_range(-4.5..4.5),
                                     ),
                                     size: AsteroidSize::Small,
                                 });
@@ -374,31 +372,31 @@ impl Entity for AsteroidEntity {
                         }
 
                         for _ in 0..6 {
-                            if rng.gen_bool(0.75) {
+                            if rng.random_bool(0.75) {
                                 callbacks.push(SpaceCallback::GenerateParticle {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     color: Rgba([
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
                                         255,
                                     ]),
                                     particle_state: EntityState::Decaying {
-                                        lifetime: 2.0 + rng.gen_range(0.0..1.5),
+                                        lifetime: 2.0 + rng.random_range(0.0..1.5),
                                     },
-                                    layer: rng.gen_range(0..=2),
+                                    layer: rng.random_range(0..=2),
                                 });
                             }
-                            if should_emit_fragments && rng.gen_bool(0.65) {
+                            if should_emit_fragments && rng.random_bool(0.65) {
                                 callbacks.push(SpaceCallback::GenerateFragment {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     resource: Resource::SCRAPS,
                                     amount: 1,
@@ -408,31 +406,31 @@ impl Entity for AsteroidEntity {
                     }
                     AsteroidSize::Small => {
                         for _ in 0..4 {
-                            if rng.gen_bool(0.35) {
+                            if rng.random_bool(0.35) {
                                 callbacks.push(SpaceCallback::GenerateParticle {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     color: Rgba([
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
-                                        55 + rng.gen_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
+                                        55 + rng.random_range(0..25),
                                         255,
                                     ]),
                                     particle_state: EntityState::Decaying {
-                                        lifetime: 2.0 + rng.gen_range(0.0..1.5),
+                                        lifetime: 2.0 + rng.random_range(0.0..1.5),
                                     },
-                                    layer: rng.gen_range(0..=2),
+                                    layer: rng.random_range(0..=2),
                                 });
                             }
-                            if should_emit_fragments && rng.gen_bool(0.75) {
+                            if should_emit_fragments && rng.random_bool(0.75) {
                                 callbacks.push(SpaceCallback::GenerateFragment {
                                     position,
                                     velocity: Vec2::new(
-                                        rng.gen_range(-3.5..3.5),
-                                        rng.gen_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
+                                        rng.random_range(-3.5..3.5),
                                     ),
                                     resource: Resource::SCRAPS,
                                     amount: 1,
@@ -464,17 +462,17 @@ impl AsteroidEntity {
         size: AsteroidSize,
         gold_fragment_probability: f64,
     ) -> Self {
-        let rng = &mut ChaCha8Rng::from_entropy();
+        let rng = &mut ChaCha8Rng::from_os_rng();
 
         let rotation_speed = if size == AsteroidSize::Planet {
             0.0
         } else {
-            rng.gen_range(-0.75..0.75) / (1 + size as usize) as f32
+            rng.random_range(-0.75..0.75) / (1 + size as usize) as f32
         };
 
         Self {
             id: 0,
-            orientation: rng.gen_range(0.0..MAX_ROTATION as f32),
+            orientation: rng.random_range(0.0..MAX_ROTATION as f32),
             rotation_speed,
             size,
             durability: size.durability(),
@@ -486,40 +484,40 @@ impl AsteroidEntity {
     }
 
     pub fn new_at_screen_edge(gold_fragment_probability: f64) -> Self {
-        let rng = &mut ChaCha8Rng::from_entropy();
+        let rng = &mut ChaCha8Rng::from_os_rng();
 
         let &size = [AsteroidSize::Small, AsteroidSize::Big, AsteroidSize::Huge]
             .iter()
             .choose_stable(rng)
             .expect("There should be at least an asteroid size");
 
-        let (position, velocity) = match rng.gen_range(0..3) {
+        let (position, velocity) = match rng.random_range(0..3) {
             // Right Edge
             0 => {
                 let x = MAX_ENTITY_POSITION.x as f32;
-                let y = rng.gen_range(
+                let y = rng.random_range(
                     0.15 * MAX_ENTITY_POSITION.y as f32..0.85 * MAX_ENTITY_POSITION.y as f32,
                 );
-                let vx = rng.gen_range(-12.5..-0.5);
-                let vy = rng.gen_range(-4.5..4.5);
+                let vx = rng.random_range(-12.5..-0.5);
+                let vy = rng.random_range(-4.5..4.5);
 
                 (Vec2::new(x, y), Vec2::new(vx, vy))
             }
             //Top edge
             1 => {
-                let x = rng.gen_range(0.45..0.85) * MAX_ENTITY_POSITION.x as f32;
+                let x = rng.random_range(0.45..0.85) * MAX_ENTITY_POSITION.x as f32;
                 let y = 0.0;
-                let vx = rng.gen_range(-4.5..4.5);
-                let vy = rng.gen_range(0.5..12.5);
+                let vx = rng.random_range(-4.5..4.5);
+                let vy = rng.random_range(0.5..12.5);
 
                 (Vec2::new(x, y), Vec2::new(vx, vy))
             }
             // Bottom edge
             2 => {
-                let x = rng.gen_range(0.45..0.85) * MAX_ENTITY_POSITION.x as f32;
+                let x = rng.random_range(0.45..0.85) * MAX_ENTITY_POSITION.x as f32;
                 let y = MAX_ENTITY_POSITION.y as f32;
-                let vx = rng.gen_range(-4.5..4.5);
-                let vy = rng.gen_range(-12.5..-0.5);
+                let vx = rng.random_range(-4.5..4.5);
+                let vy = rng.random_range(-12.5..-0.5);
 
                 (Vec2::new(x, y), Vec2::new(vx, vy))
             }
@@ -531,12 +529,12 @@ impl AsteroidEntity {
     }
 
     pub fn planet() -> Self {
-        let rng = &mut ChaCha8Rng::from_entropy();
+        let rng = &mut ChaCha8Rng::from_os_rng();
 
         let x = MAX_ENTITY_POSITION.x as f32;
-        let y = rng.gen_range(0.25..0.45) * MAX_ENTITY_POSITION.y as f32;
-        let vx = rng.gen_range(-4.0..-3.0);
-        let vy = rng.gen_range(-0.25..0.25);
+        let y = rng.random_range(0.25..0.45) * MAX_ENTITY_POSITION.y as f32;
+        let vx = rng.random_range(-4.0..-3.0);
+        let vy = rng.random_range(-0.25..0.25);
 
         Self::new(
             Vec2::new(x, y),
