@@ -6,7 +6,7 @@ use super::ui_callback::UiCallback;
 use super::ui_frame::UiFrame;
 use super::widgets::{space_adventure_button, thick_block};
 use super::{traits::Screen, widgets::default_block};
-use crate::types::{AppResult, PlayerId, SystemTimeTick, TeamId, Tick};
+use crate::types::{AppResult, PlayerId, SystemTimeTick, TeamId};
 use crate::ui::constants::*;
 use crate::world::skill::Rated;
 use crate::world::types::PlayerLocation;
@@ -292,7 +292,7 @@ impl GalaxyPanel {
                 TeamLocation::OnPlanet { planet_id } => {
                     let duration = world.travel_time_to_planet(own_team.id, planet.id)?;
                     let hover_text = format!(
-                        "Travel to {}: Distance {} AU - Time {} - Fuel {}",
+                        "Travel to {}: Distance {} AU - Duration {} - Fuel {}",
                         planet.name,
                         world.distance_between_planets(planet_id, planet.id)? as f32 / AU as f32,
                         duration.formatted(),
@@ -328,11 +328,9 @@ impl GalaxyPanel {
                     ..
                 } => {
                     let text = if to == planet.id {
-                        let countdown = if started + duration > world.last_tick_short_interval {
-                            (started + duration - world.last_tick_short_interval).formatted()
-                        } else {
-                            (0 as Tick).formatted()
-                        };
+                        let countdown = (started + duration)
+                            .saturating_sub(world.last_tick_short_interval)
+                            .formatted();
                         format!("Getting there ({})", countdown)
                     } else {
                         "Travel".to_string()
