@@ -7,10 +7,11 @@ use super::{
     traits::{Screen, SplitPanel},
     widgets::default_block,
 };
+use crate::audio::AudioPlayerState;
 use crate::store::world_file_data;
 use crate::types::{AppResult, SystemTimeTick, Tick};
 use crate::world::constants::{DEBUG_TIME_MULTIPLIER, SOL_ID};
-use crate::{store::world_exists, world::world::World};
+use crate::{store::save_game_exists, world::world::World};
 use core::fmt::Debug;
 use crossterm::event::KeyCode;
 use rand::seq::IndexedRandom;
@@ -26,13 +27,6 @@ use std::vec;
 const TITLE_WIDTH: u16 = 71;
 const BUTTON_WIDTH: u16 = 36;
 
-#[derive(Debug, PartialEq)]
-pub enum AudioPlayerState {
-    Playing,
-    Paused,
-    Disabled,
-}
-
 #[derive(Debug)]
 pub struct SplashScreen {
     index: usize,
@@ -45,7 +39,7 @@ pub struct SplashScreen {
     gif_map: GifMap,
 }
 
-const QUOTES: [&'static str;18] = [
+const QUOTES: [&'static str;19] = [
     " “What cannot be destroyed can, nonetheless, be diverted, frozen, transformed, and gradually deprived of its substance - which in the case of states, is ultimately their capacity to inspire terror.” - D. Graeber",
     " “Aber der Staat lügt in allen Zungen des Guten und Bösen; und was er auch redet, er lügt—und was er auch hat, gestohlen hat er's.” - F. Nietzsche",
     " “That is what I have always understood to be the essence of anarchism: the conviction that the burden of proof has to be placed on authority, and that it should be dismantled if that burden cannot be met.” - N. Chomsky",
@@ -65,6 +59,7 @@ const QUOTES: [&'static str;18] = [
     " “There is now a widespread tendency to argue that one can only defend democracy by totalitarian methods. If one loves democracy, the argument runs, one must crush its enemies by no matter what means. [..] In other words, defending democracy involves destroying all independence of thought.” - G. Orwell",
     " “Van a envejecer y van a tener arrugas, y un día se van a mirar en el espejo y tendrán que preguntarse, ese día, si traicionaron al niño que tenían adentro.” - José 'Pepe' Mujica",
     " “Se ha generado una literatura contra el Estado falsa. Pero el Estado es como la caja de herramientas, no tiene conciencia. Los que fallamos somos los humanos que manejamos el Estado.” - José 'Pepe' Mujica",    
+    " “Chi trova il coraggio di costruire la propria esistenza nel mare mosso dell’incerto riuscirà più facilmente a trovare il proprio spazio nel presente di chi invece tenta di gettare l’ancora verso i lidi di epoche passate.” - Alexander Langer"
     ];
 
 const TITLE: [&'static str; 13] = [
@@ -90,7 +85,7 @@ impl SplashScreen {
         let mut can_load_world = false;
         let mut continue_text = "Continue".to_string();
 
-        if world_exists(store_prefix) {
+        if save_game_exists(store_prefix) {
             if let Ok(continue_data) = world_file_data(store_prefix) {
                 if let Ok(last_modified) = continue_data.modified() {
                     continue_text = format!(
