@@ -234,6 +234,8 @@ pub enum UiCallback {
     SpaceToggleAutofire,
     SpaceShoot,
     SpaceReleaseScraps,
+    ToggleTeamAutonomousStrategyForLocalChallenges,
+    ToggleTeamAutonomousStrategyForNetworkChallenges,
 }
 
 impl UiCallback {
@@ -275,7 +277,6 @@ impl UiCallback {
 
     fn go_to_trade(trade: Trade) -> AppCallback {
         Box::new(move |app: &mut App| {
-            app.ui.player_panel.update(&app.world)?;
             app.ui.player_panel.reset_view();
 
             // Display trade differently depending on who is the proposer.
@@ -309,14 +310,19 @@ impl UiCallback {
         Box::new(move |app: &mut App| {
             let team_id = app
                 .world
-                .get_player(&player_id)
-                .ok_or(anyhow!("Player {:?} not found", player_id))?
+                .get_player_or_err(&player_id)?
                 .team
                 .ok_or(anyhow!("Player {:?} has no team", player_id))?;
 
             app.ui.team_panel.reset_view();
 
-            if let Some(index) = app.ui.team_panel.teams.iter().position(|&x| x == team_id) {
+            if let Some(index) = app
+                .ui
+                .team_panel
+                .all_teams
+                .iter()
+                .position(|&x| x == team_id)
+            {
                 app.ui.team_panel.set_index(index);
                 let player_index = app
                     .world
@@ -1176,7 +1182,7 @@ impl UiCallback {
             }
             UiCallback::ToggleAudio => {
                 if let Some(player) = app.audio_player.as_mut() {
-                    player.toggle()?;
+                    player.toggle_state()?;
                 } else {
                     info!("No audio player, cannot toggle it");
                 }
@@ -1185,7 +1191,7 @@ impl UiCallback {
             }
             UiCallback::PreviousRadio => {
                 if let Some(player) = app.audio_player.as_mut() {
-                    player.previous_audio_sample()?;
+                    player.previous_radio_stream()?;
                 } else {
                     info!("No audio player, cannot select previous sample");
                 }
@@ -1193,7 +1199,7 @@ impl UiCallback {
             }
             UiCallback::NextRadio => {
                 if let Some(player) = app.audio_player.as_mut() {
-                    player.next_audio_sample()?;
+                    player.next_radio_stream()?;
                 } else {
                     info!("No audio player, cannot select next sample");
                 }
@@ -1631,6 +1637,20 @@ impl UiCallback {
 
                 Ok(None)
             }
+
+            UiCallback::ToggleTeamAutonomousStrategyForLocalChallenges => {
+                let own_team = app.world.get_own_team_mut()?;
+                own_team.autonomous_strategy.challenge_local =
+                    !own_team.autonomous_strategy.challenge_local;
+                Ok(None)
+            }
+
+            UiCallback::ToggleTeamAutonomousStrategyForNetworkChallenges => {
+                let own_team = app.world.get_own_team_mut()?;
+                own_team.autonomous_strategy.challenge_network =
+                    !own_team.autonomous_strategy.challenge_network;
+                Ok(None)
+            }
         }
     }
 }
